==> sc-gitlab-webhook-0.0.5.tar.gz: sc-gitlab-webhook-0.0.5/webhook/views.py <==
#  The MIT License (MIT)
#
#  Copyright (c) 2021. Scott Lau
#
#  Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.


import logging

from flask import request, abort

from webhook import server, msg_queue_handler
from webhook.exceptions import SendMsgException


@server.route('/hello')
def hello():
    return 'Hello, World'


@server.route('/webhook', methods=['POST'])
def webhook():
    request_json = request.json
    if not request_json:
        logging.getLogger(__name__).error("no request json")
        abort(400)
    try:
        msg_queue_handler.handle(str(request_json))
    except SendMsgException as e:
        abort(500, e)
    return 'OK'

==> sc-gitlab-webhook-0.0.6.tar.gz: sc-gitlab-webhook-0.0.6/webhook/views.py <==
#  The MIT License (MIT)
#
#  Copyright (c) 2021. Scott Lau
#
#  Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.


import logging
import json

from flask import request, abort

from webhook import server, msg_queue_handler
from webhook.exceptions import SendMsgException


@server.route('/hello')
def hello():
    return 'Hello, World'


@server.route('/webhook', methods=['POST'])
def webhook():
    request_json_dict = request.json
    if not request_json_dict:
        logging.getLogger(__name__).error("no request json")
        abort(400)
    try:
        # dump dict as json string
        request_json = json.dumps(request_json_dict)
        msg_queue_handler.handle(request_json)
    except SendMsgException as e:
        abort(500, e)
    return 'OK'
